@@ -1,14 +1,54 @@
+use std::{
+    collections::HashMap,
+    fs,
+    path::PathBuf,
+    time::{Duration, SystemTime},
+};
+
 use anyhow::Context;
-use std::{collections::HashMap, fs, path::PathBuf};
+use git2::Repository;
+use spinners::{Spinner, Spinners};
 
 mod purge;
 use crate::lib::CACHE_DIR;
 pub use purge::purge;
 
+const TO_UPDATE: u64 = 360 * 24;
+
+fn clone_repo(url: &str, cache_dir: &str) -> anyhow::Result<Repository> {
+    let mut sp = Spinner::new(Spinners::Dots12, "Initializing Cache...".into());
+
+    let r = Repository::clone(url, cache_dir)
+        .with_context(|| "Failed to clone gitignore repository")?;
+
+    sp.stop_with_message("Cache Initialized!".into());
+
+    Ok(r)
+}
+
 pub fn init_cache() -> anyhow::Result<PathBuf> {
     if let Some(cache_dir) = CACHE_DIR.to_owned() {
-        if !cache_dir.exists() {
-            fs::create_dir_all(&cache_dir).with_context(|| "Failed to create cache directory")?;
+        let url = "https://github.com/github/gitignore.git";
+        let fetch_path = cache_dir.join(".git").join("FETCH_HEAD");
+
+        if !fetch_path.exists() {
+            fs::remove_dir_all(&cache_dir)?;
+            clone_repo(url, cache_dir.to_str().unwrap())?;
+
+            return Ok(cache_dir);
+        }
+
+        let fetch_meta = fetch_path.metadata()?;
+        let last_modified = fetch_meta.modified()?;
+        let now = SystemTime::now();
+
+        let since = now
+            .duration_since(last_modified)
+            .unwrap_or(Duration::from_secs(TO_UPDATE))
+            .as_secs();
+
+        if since > TO_UPDATE {
+            clone_repo(url, cache_dir.to_str().unwrap())?;
         }
 
         Ok(cache_dir)
