@@ -1,7 +1,7 @@
 use clap::{Arg, Parser, Subcommand};
 
 #[derive(Parser, Debug)]
-#[clap(author, version, about, long_about = None)]
+#[clap(author, version, about)]
 pub struct Args {
     #[clap(subcommand)]
     pub command: Commands,
@@ -18,11 +18,6 @@ pub enum Commands {
     ])]
     Pull,
 
-    #[cfg(feature = "cache")]
     #[clap(about = "Purge gitignore cache")]
     Purge,
 }
-
-pub fn parse() -> Args {
-    Args::parse()
-}
