@@ -1,19 +1,17 @@
 #[macro_export]
 macro_rules! flush_stdout {
-    () => {{
+    () => {
         io::stdout()
             .flush()
-            .with_context(|| "Failed to flush stdout")?;
-    }};
+            .with_context(|| "Failed to flush stdout")?
+    };
 }
 
 #[macro_export]
 macro_rules! create_client {
-    () => {{
-        use reqwest::blocking::Client;
-
-        Client::new()
-    }};
+    () => {
+        reqwest::blocking::Client::new()
+    };
 }
 
 #[macro_export]
@@ -25,10 +23,10 @@ macro_rules! sleep_for {
 
 #[macro_export]
 macro_rules! parse_url {
-    ($url:tt) => {{
+    ($url:tt) => {
         format!(
             "https://raw.githubusercontent.com/github/gitignore/main/{}.gitignore",
             $url
         )
-    }};
+    };
 }
